@@ -54,6 +54,8 @@ private:
     void PrintTracks();
 
 private slots:
+    /* Ui related */
+    void on_cbPlaylists_currentIndexChanged(QString );
     void on_pushButton_clicked();
     void on_pushButton_2_clicked();
     void on_pushButton_3_clicked();
@@ -66,9 +68,16 @@ private slots:
     void on_pushButton_5_clicked();
     void on_pbLogin_clicked();
 
+    /* Despotify-wrapper related */
     void PlaylistsUpdated();
     void NewTrack(int min, int sec, int totsec, track *t);
     void TellTime(int min, int sec, int totsec);
+
+    /* Player related */
+    void Playing();
+    void Paused();
+    void Exiting();
+
 };
 
 
